/**
 * \addtogroup Types
 * @{
 */

/*****************************************************************************/
/**
 * \file types.h
 * Intrinsic datatype portability redefinitions for Keil C51.
 * \author Copyright (c) 2005, Murray R. Van Luyn. <vanluynm@iinet.net.au>
 * \version 0.0
 * \date 24-06-05
 */
/*****************************************************************************/

/*****************************************************************************
 *
 *     THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS
 *     OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 *     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 *     ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY
 *     DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 *     DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 *     GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 *     INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 *     WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *     NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************/

#ifndef TYPES_H
#define TYPES_H

/*****************************************************************************
 *
 *                         Portable datatype definitions
 *
 *****************************************************************************/

/** 
 * Boolean 1 bit datatype.
 * Range 0 to 1
 *
 * Functions that disable interrupts (#pragma disable) and functions that are
 * declared using an explicit register bank (using n) cannot return a boolean_t
 * value. A boolean_t cannot be declared as a pointer. An array of type bit is
 * also invalid.
 */
typedef bit bool_t;

/** 
 * Signed 8 bit datatype.
 * Range -128 to +127
 */
typedef signed char s8_t;

/** 
 * Unsigned 8 bit datatype.
 * Range 0 to 255
 */
typedef unsigned char u8_t;

/** 
 * Signed 16 bit datatype.
 * Range -32768 to +32767
 */
typedef signed int s16_t;

/** 
 * Unsigned 16 bit datatype.
 * Range 0 to 65535
 */
typedef unsigned int u16_t;

/** 
 * Signed 32 bit datatype.
 * Range -2147483648 to +2147483647
 */
typedef signed long s32_t;

/** 
 * Unsigned 32 bit datatype.
 * Range 0 to 4294967295
 */
typedef unsigned long u32_t;

/** 
 * Floating point 32 bit datatype.
 * Range 1.175494E-38 to 3.402823E+38
 */
typedef float f32_t;

#endif

/** @} */
